@@ -215,6 +215,7 @@ UpgradeStepType = Literal["PRE_UPGRADE_CHECK", "SNAPSHOT", "UPGRADE"]
 VolumeTypeType = Literal["gp2", "io1", "standard"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -247,6 +248,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
